@@ -1,6 +1,6 @@
 /// An error that occurs when initializing the block length LV2 feature.
 #[derive(Copy, Clone, Debug)]
-pub enum InitializeBlockLength {
+pub enum InitializeBlockLengthError {
     /// The minimum block length is too large.
     MinBlockLengthTooLarge { max_supported: usize, actual: usize },
     /// The maximum block length is too large.
@@ -15,7 +15,7 @@ pub enum InitializeBlockLength {
 
 /// An error with plugin instantiation.
 #[derive(Copy, Clone, Debug)]
-pub enum Instantiate {
+pub enum InstantiateError {
     /// An error ocurred, but it is not known why.
     UnknownError,
     /// `World::initialize_block_length` has not yet been called.
@@ -23,8 +23,8 @@ pub enum Instantiate {
 }
 
 /// An error that occurs when dealing with atom events.
-#[derive(Copy, Clone, Debug)]
-pub enum Event {
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
+pub enum EventError {
     /// The size of the data is too large than what is supported for the event.
     DataTooLarge {
         max_supported_size: usize,
@@ -32,12 +32,12 @@ pub enum Event {
     },
 
     /// The size of the sequence has exceeded its capacity.
-    SequenceCapacityExceeded,
+    SequenceFull { capacity: usize, requested: usize },
 }
 
 /// An error associated with running a plugin.
 #[derive(Debug)]
-pub enum Run {
+pub enum RunError {
     /// The number of control inputs was different than what the plugin
     /// required.
     ControlInputsSizeMismatch { expected: usize, actual: usize },
@@ -59,4 +59,10 @@ pub enum Run {
     /// The number of atom sequence outputs was different than what the plugin
     /// required.
     AtomSequenceOutputsSizeMismatch { expected: usize, actual: usize },
+
+    /// The number of cv inputs was different than what the plugin required.
+    CVInputsSizeMismatch { expected: usize, actual: usize },
+
+    /// The number of cv outputs was different than what the plugin required.
+    CVOutputsSizeMismatch { expected: usize, actual: usize },
 }
